@@ -130,7 +130,8 @@ There is NO WARRANTY, to the extent permitted by law.
                                                 (not (string-null? line)))
                                        (unless parse?
                                          (eval-sh ast))
-                                       (add-history line))
+                                       (add-history line)
+                                       (reap-child-processes!))
                                      (loop (let ((previous (if ast "" (string-append line "\n")))
                                                  (next (readline (if ast (prompt) "> "))))
                                              (if (eof-object? next) next
