@@ -1,5 +1,5 @@
 ;;; Gash -- Guile As SHell
-;;; Copyright © 2018, 2019 Timothy Sample <samplet@ngyro.com>
+;;; Copyright © 2018, 2019, 2020 Timothy Sample <samplet@ngyro.com>
 ;;;
 ;;; This file is part of Gash.
 ;;;
@@ -26,6 +26,7 @@
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-26)
   #:export (sh:and
+            sh:async
             sh:case
             sh:cond
             sh:exec-let
@@ -191,8 +192,11 @@ if it is our responsibility to close the port."
     (('< (? integer? fd) (? string? filename))
      (make-processed-redir fd filename O_RDONLY))
     (('> (? integer? fd) (? string? filename))
-     ;; TODO: Observe noclobber.
-     (make-processed-redir fd filename (logior O_WRONLY O_CREAT O_TRUNC)))
+     (let* ((clobber-flags (logior O_WRONLY O_CREAT O_TRUNC))
+            (flags (if (getopt 'noclobber)
+                       (logior clobber-flags O_EXCL)
+                       clobber-flags)))
+       (make-processed-redir fd filename flags)))
     (('>! (? integer? fd) (? string? filename))
      (make-processed-redir fd filename (logior O_WRONLY O_CREAT O_TRUNC)))
     (('>> fd filename)
@@ -438,3 +442,12 @@ of each thunk sent to the input of the next thunk."
        (if (= (get-status) 0)
            (thunk)
            (loop tail))))))
+
+
+;;; Asynchronous commands.
+
+(define (sh:async thunk)
+  "Run @var{thunk} asynchronously."
+  (let ((pid (%subshell thunk)))
+    (set-last-job! pid)
+    (set-status! 0)))
